﻿using DocumentFormat.OpenXml.Office2013.Excel;
using Exam.Infrastructure.Web.Utilities;
using Exam.Practices;
using Exam.Questions;
using Hotline.Application.Exam.Core.Extensions;
using Hotline.Application.Exam.Extensions;
using Hotline.Share.Enums.Exams;
using Hotline.Share.Requests.Exam;
using Hotline.Share.Requests.TestPaper;
using JiebaNet.Segmenter.Common;
using System.Linq.Expressions;

namespace Hotline.Application.Exam.QueryExtensions.Practices
{
    public static class PracticeQueryExtensions
    {
        public static Expression<Func<Practice,bool>> GetExpression(this PracticePagedRequest practicePagedRequest)
        {
            Expression<Func<Practice, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<Practice>()
                .ToExpression();

            return expression;
        }

        public static Expression<Func<PracticeQuestion,bool>> GetExpression(this PracticeQuestionGroupRequest practiceQuestionGroupRequest)
        {
            Expression<Func<PracticeQuestion, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<PracticeQuestion>()
                .AndIF(practiceQuestionGroupRequest.PracticeId.IsNotNull(),x=>x.PracticeId == practiceQuestionGroupRequest.PracticeId)
                .ToExpression();

            return expression;
        }

        public static Expression<Func<PracticeQuestion,bool>> GetExpression(this PracticeQuestionRequest practiceQuestionRequest)
        {
            Expression<Func<PracticeQuestion, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<PracticeQuestion>()
                .AndIF(practiceQuestionRequest.PracticeQuestionId.IsNotNull(), x => x.Id == practiceQuestionRequest.PracticeQuestionId)
                .ToExpression();

            return expression;
        }

        public static Expression<Func<QuestionTag, bool>> GetExpression(this TagQuestionCountForPracticeRequest tagQuestionCountForPracticeRequest)
        {
            Expression<Func<QuestionTag, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<QuestionTag>()
               .AndIF(tagQuestionCountForPracticeRequest.TagIds.IsNotNullOrEmpty() && tagQuestionCountForPracticeRequest.TagIds.Any(), x => tagQuestionCountForPracticeRequest.TagIds.Contains(x.TagId))               
               .ToExpression();

            return expression;
        }

        public static Expression<Func<Question, bool>> GetQuestionExpression(this TagQuestionCountForPracticeRequest tagQuestionCountForPracticeRequest)
        {
            Expression<Func<Question, bool>> expression = m => m.Id != null;
            expression = ExpressionableUtility.CreateExpression<Question>()
            .And(x=>x.QuestionType == EQuestionType.Single || x.QuestionType == EQuestionType.Multi || x.QuestionType == EQuestionType.Judge)
            .ToExpression();

            return expression;
        }
    }
}
